@@ -5,30 +5,27 @@ use crate::{key::store::GeneratePkcs8, Error, Result};
 use alloc::boxed::Box;
 use core::fmt;
 use ed25519_dalek::SECRET_KEY_LENGTH;
-use pkcs8::DecodePrivateKey;
 use rand_core::{OsRng, RngCore};
 use signature::Signer;
 use zeroize::Zeroizing;
 
 /// Ed25519 signing key.
 pub struct SigningKey {
-    inner: Box<dyn Ed25519Signer>,
+    inner: Box<dyn Ed25519Signer + Send + Sync>,
 }
 
 impl SigningKey {
     /// Initialize from a provided signer object.
     ///
     /// Use [`SigningKey::from_bytes`] to initialize from a raw private key.
-    pub fn new(signer: Box<dyn Ed25519Signer>) -> Self {
+    pub fn new(signer: Box<dyn Ed25519Signer + Send + Sync>) -> Self {
         Self { inner: signer }
     }
 
     /// Initialize from a raw scalar value (big endian).
     pub fn from_bytes(bytes: &[u8]) -> Result<Self> {
-        let secret = ed25519_dalek::SecretKey::from_bytes(bytes).map_err(|_| Error::Parse)?;
-        let public = ed25519_dalek::PublicKey::from(&secret);
-        let keypair = ed25519_dalek::Keypair { secret, public };
-        Ok(Self::new(Box::new(keypair)))
+        let signing_key = ed25519_dalek::SigningKey::try_from(bytes).map_err(|_| Error::Parse)?;
+        Ok(Self::new(Box::new(signing_key)))
     }
 
     /// Get the verifying key that corresponds to this signing key.
@@ -37,8 +34,6 @@ impl SigningKey {
     }
 }
 
-impl DecodePrivateKey for SigningKey {}
-
 // TODO(tarcieri): use upstream decoder from `ed25519` crate.
 // See: https://docs.rs/ed25519/latest/ed25519/pkcs8/struct.KeypairBytes.html
 impl TryFrom<pkcs8::PrivateKeyInfo<'_>> for SigningKey {
@@ -56,14 +51,12 @@ impl TryFrom<pkcs8::PrivateKeyInfo<'_>> for SigningKey {
 }
 
 #[cfg(feature = "std")]
-#[cfg_attr(docsrs, doc(cfg(feature = "std")))]
 impl GeneratePkcs8 for SigningKey {
     /// Randomly generate a new PKCS#8 private key.
-    fn generate_pkcs8() -> pkcs8::PrivateKeyDocument {
+    fn generate_pkcs8() -> pkcs8::SecretDocument {
         let mut private_key = Zeroizing::new([0u8; SECRET_KEY_LENGTH]);
         OsRng.fill_bytes(&mut *private_key);
-        pkcs8::PrivateKeyInfo::new(ALGORITHM_ID, &*private_key)
-            .to_der()
+        pkcs8::SecretDocument::encode_msg(&pkcs8::PrivateKeyInfo::new(ALGORITHM_ID, &*private_key))
             .expect("DER encoding error")
     }
 }
